@@ -22,10 +22,10 @@
  * SOFTWARE.
  */
 use super::ui::{
-    activity::{main::MainActivity, Activity, ExitReason},
+    activity::{main::TermusicActivity, Activity, ExitReason},
     context::Context,
 };
-use crate::config::TermusicConfig;
+use crate::config::Termusic;
 use std::time::Instant;
 
 use log::error;
@@ -33,7 +33,7 @@ use std::thread::sleep;
 use std::time::Duration;
 
 pub struct App {
-    pub config: TermusicConfig,
+    pub config: Termusic,
     pub quit: bool,           // Becomes true when the user presses <ESC>
     pub redraw: bool,         // Tells whether to refresh the UI; performance optimization
     pub last_redraw: Instant, // Last time the ui has been redrawed
@@ -41,14 +41,14 @@ pub struct App {
 }
 
 impl App {
-    pub fn new(config: TermusicConfig) -> Self {
+    pub fn new(config: Termusic) -> Self {
         let mut ctx: Context = Context::new();
         // Enter alternate screen
         ctx.enter_alternate_screen();
         // Clear screen
         ctx.clear_screen();
 
-        App {
+        Self {
             config,
             quit: false,
             redraw: true,
@@ -58,14 +58,13 @@ impl App {
     }
 
     pub fn run(&mut self) {
-        let mut main_activity: MainActivity = MainActivity::default();
+        let mut main_activity: TermusicActivity = TermusicActivity::default();
         // Get context
-        let ctx: Context = match self.context.take() {
-            Some(ctx) => ctx,
-            None => {
-                error!("Failed to start MainActivity: context is None");
-                return;
-            }
+        let ctx: Context = if let Some(ctx) = self.context.take() {
+            ctx
+        } else {
+            error!("Failed to start MainActivity: context is None");
+            return;
         };
         // Create activity
         main_activity.init_config(&self.config);
@@ -73,6 +72,7 @@ impl App {
         let mut progress_interval = 0;
         loop {
             main_activity.update_message();
+            main_activity.update_queue_items();
             if progress_interval == 0 {
                 main_activity.update_progress();
                 main_activity.run();
@@ -81,7 +81,7 @@ impl App {
             }
             progress_interval += 1;
             if progress_interval >= 8 {
-                progress_interval = 0
+                progress_interval = 0;
             }
 
             // Draw activity
