@@ -21,7 +21,7 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-use super::{MainActivity, COMPONENT_TREEVIEW};
+use super::{TermusicActivity, COMPONENT_TREEVIEW};
 use anyhow::{bail, Result};
 use pinyin::ToPinyin;
 use std::fs::{remove_dir_all, remove_file, rename};
@@ -30,7 +30,7 @@ use tui_realm_treeview::{Node, Tree, TreeViewPropsBuilder};
 use tuirealm::event::{Event, KeyCode, KeyEvent, KeyModifiers};
 use tuirealm::{Payload, PropsBuilder, Value};
 
-impl MainActivity {
+impl TermusicActivity {
     pub fn scan_dir(&mut self, p: &Path) {
         self.path = p.to_path_buf();
         self.tree = Tree::new(Self::dir_tree(p, 3));
@@ -48,7 +48,7 @@ impl MainActivity {
         let mut node: Node = Node::new(p.to_string_lossy().into_owned(), name);
         if depth > 0 && p.is_dir() {
             if let Ok(paths) = std::fs::read_dir(p) {
-                let mut paths: Vec<_> = paths.filter_map(|r| r.ok()).collect();
+                let mut paths: Vec<_> = paths.filter_map(std::result::Result::ok).collect();
 
                 paths.sort_by_cached_key(|k| {
                     get_pin_yin(&k.file_name().to_string_lossy().to_string())
@@ -65,7 +65,7 @@ impl MainActivity {
         let mut children: Vec<String> = vec![];
         if p.is_dir() {
             if let Ok(paths) = std::fs::read_dir(p) {
-                let mut paths: Vec<_> = paths.filter_map(|r| r.ok()).collect();
+                let mut paths: Vec<_> = paths.filter_map(std::result::Result::ok).collect();
 
                 paths.sort_by_cached_key(|k| {
                     get_pin_yin(&k.file_name().to_string_lossy().to_string())
@@ -154,10 +154,11 @@ impl MainActivity {
                     let pold: &Path = Path::new(old_id.as_str());
                     if let Some(p_parent) = p.parent() {
                         if let Some(pold_filename) = pold.file_name() {
-                            let mut new_node_id = p_parent.join(pold_filename);
-                            if p.is_dir() {
-                                new_node_id = p.join(pold_filename);
-                            }
+                            let new_node_id = if p.is_dir() {
+                                p.join(pold_filename)
+                            } else {
+                                p_parent.join(pold_filename)
+                            };
                             rename(pold, new_node_id.as_path())?;
                             self.sync_playlist(new_node_id.to_str());
                         }
@@ -190,6 +191,7 @@ fn get_pin_yin(input: &str) -> String {
 }
 
 #[cfg(test)]
+#[allow(clippy::non_ascii_literal)]
 mod tests {
 
     use crate::ui::activity::main::playlist::get_pin_yin;
