@@ -21,29 +21,30 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-use super::MainActivity;
+use super::TermusicActivity;
 use super::{COMPONENT_TABLE_QUEUE, COMPONENT_TREEVIEW};
 
 use crate::config::get_app_config_path;
 use crate::song::Song;
-use anyhow::{bail, Result};
+use anyhow::Result;
 use humantime::format_duration;
 use rand::seq::SliceRandom;
 use rand::thread_rng;
+use std::collections::VecDeque;
 use std::fs::File;
 use std::io::{BufRead, BufReader, Write};
 use std::path::Path;
 use std::str::FromStr;
+use std::thread;
 use std::time::Duration;
 use tui_realm_stdlib::TablePropsBuilder;
 use tuirealm::PropsBuilder;
 
 use tuirealm::props::{TableBuilder, TextSpan};
 
-impl MainActivity {
+impl TermusicActivity {
     pub fn add_queue(&mut self, item: Song) {
-        self.queue_items.insert(0, item);
-
+        self.queue_items.push_front(item);
         self.sync_queue();
     }
 
@@ -55,15 +56,12 @@ impl MainActivity {
                 table.add_row();
             }
 
-            let mut duration = record.duration().to_string();
-            duration.truncate(6);
-            let duration_string = format!("[{:^6}]", duration);
+            let duration = record.duration_formatted().to_string();
+            let duration_string = format!("[{:^6.6}]", duration);
 
-            let name = record
-                .name
-                .to_owned()
-                .unwrap_or_else(|| "No Name".to_string());
-            let artist = record.artist().unwrap_or(&name);
+            let noname_string = "No Name".to_string();
+            let name = record.name().unwrap_or(&noname_string);
+            let artist = record.artist().unwrap_or(name);
             let title = record.title().unwrap_or("Unknown Title");
 
             table
@@ -110,8 +108,8 @@ impl MainActivity {
         path.push("queue.log");
 
         let mut file = File::create(path.as_path())?;
-        for i in self.queue_items.iter().rev() {
-            if let Some(f) = &i.file {
+        for i in &self.queue_items {
+            if let Some(f) = i.file() {
                 writeln!(&mut file, "{}", f)?;
             }
         }
@@ -123,13 +121,11 @@ impl MainActivity {
         let mut path = get_app_config_path()?;
         path.push("queue.log");
 
-        let file = match File::open(path.as_path()) {
-            Ok(f) => f,
-            Err(_) => {
-                File::create(path.as_path())?;
-
-                File::open(path)?
-            }
+        let file = if let Ok(f) = File::open(path.as_path()) {
+            f
+        } else {
+            File::create(path.as_path())?;
+            File::open(path)?
         };
         let reader = BufReader::new(file);
         let lines: Vec<_> = reader
@@ -137,32 +133,33 @@ impl MainActivity {
             .map(|line| line.unwrap_or_else(|_| "Error".to_string()))
             .collect();
 
-        for line in lines.iter() {
-            match Song::from_str(line) {
-                Ok(s) => self.queue_items.insert(0, s),
-                Err(e) => bail!("song add to queue error: {}", e),
-            };
-        }
+        let tx = self.sender_queueitems.clone();
 
-        self.sync_queue();
+        thread::spawn(move || {
+            let mut queue_items = VecDeque::new();
+            for line in &lines {
+                if let Ok(s) = Song::from_str(line) {
+                    queue_items.push_back(s);
+                };
+            }
+            let _drop = tx.send(queue_items);
+        });
 
         Ok(())
     }
 
     pub fn shuffle(&mut self) {
         let mut rng = thread_rng();
-        self.queue_items.shuffle(&mut rng);
+        self.queue_items.make_contiguous().shuffle(&mut rng);
         self.sync_queue();
     }
 
     pub fn update_item_delete(&mut self) {
         self.queue_items.retain(|x| {
-            if let Some(p) = &x.file {
+            x.file().map_or(false, |p| {
                 let path = Path::new(p);
                 path.exists()
-            } else {
-                false
-            }
+            })
         });
 
         self.sync_queue();
@@ -170,11 +167,11 @@ impl MainActivity {
     }
     pub fn update_title(&self) -> String {
         let mut duration = Duration::from_secs(0);
-        for v in self.queue_items.iter() {
-            duration += v.duration;
+        for v in &self.queue_items {
+            duration += v.duration();
         }
         format!(
-            "─ Queue ───┤ Total {} songs | {} ├─",
+            "\u{2500} Queue \u{2500}\u{2500}\u{2500}\u{2524} Total {} songs | {} \u{251c}\u{2500}",
             self.queue_items.len(),
             format_duration(Duration::new(duration.as_secs(), 0))
         )
