@@ -25,13 +25,26 @@
 use std::str::FromStr;
 // ext
 use super::{
-    youtube_options::YoutubeSearchState, ExitReason, MainActivity, MessageState, Status,
-    StatusLine, TransferState, COMPONENT_CONFIRMATION_INPUT, COMPONENT_CONFIRMATION_RADIO,
+    youtube_options::YoutubeSearchState, ExitReason, MessageState, Status, StatusLine,
+    TermusicActivity, TransferState, COMPONENT_CONFIRMATION_INPUT, COMPONENT_CONFIRMATION_RADIO,
     COMPONENT_INPUT_URL, COMPONENT_LABEL_HELP, COMPONENT_PARAGRAPH_LYRIC, COMPONENT_PROGRESS,
     COMPONENT_TABLE_QUEUE, COMPONENT_TABLE_YOUTUBE, COMPONENT_TEXT_ERROR, COMPONENT_TEXT_HELP,
     COMPONENT_TREEVIEW,
 };
-use crate::{player::AudioPlayer, song::Song, songtag::lrc::Lyric, ui::keymap::*};
+use crate::{
+    player::Generic,
+    song::Song,
+    songtag::lrc::Lyric,
+    ui::keymap::{
+        MSG_KEY_BACKSPACE, MSG_KEY_CHAR_B, MSG_KEY_CHAR_CAPITAL_B, MSG_KEY_CHAR_CAPITAL_D,
+        MSG_KEY_CHAR_CAPITAL_F, MSG_KEY_CHAR_CAPITAL_G, MSG_KEY_CHAR_CAPITAL_L,
+        MSG_KEY_CHAR_CAPITAL_Q, MSG_KEY_CHAR_CAPITAL_T, MSG_KEY_CHAR_D, MSG_KEY_CHAR_DASH,
+        MSG_KEY_CHAR_EQUAL, MSG_KEY_CHAR_F, MSG_KEY_CHAR_G, MSG_KEY_CHAR_H, MSG_KEY_CHAR_J,
+        MSG_KEY_CHAR_K, MSG_KEY_CHAR_L, MSG_KEY_CHAR_MINUS, MSG_KEY_CHAR_N, MSG_KEY_CHAR_P,
+        MSG_KEY_CHAR_PLUS, MSG_KEY_CHAR_R, MSG_KEY_CHAR_S, MSG_KEY_CHAR_T, MSG_KEY_CHAR_Y,
+        MSG_KEY_CTRL_H, MSG_KEY_ENTER, MSG_KEY_ESC, MSG_KEY_SHIFT_TAB, MSG_KEY_SPACE, MSG_KEY_TAB,
+    },
+};
 use humantime::format_duration;
 use std::path::{Path, PathBuf};
 use std::thread::{self, sleep};
@@ -45,11 +58,16 @@ use tuirealm::{
     Msg, Payload, PropsBuilder, Value,
 };
 
-impl MainActivity {
+impl TermusicActivity {
     /// ### update
     ///
     /// Update auth activity model based on msg
     /// The function exits when returns None
+    #[allow(
+        clippy::too_many_lines,
+        clippy::needless_pass_by_value,
+        clippy::cognitive_complexity
+    )]
     pub(super) fn update(&mut self, msg: Option<(String, Msg)>) -> Option<(String, Msg)> {
         let ref_msg: Option<(&str, &Msg)> = msg.as_ref().map(|(s, msg)| (s.as_str(), msg));
         match ref_msg {
@@ -108,36 +126,30 @@ impl MainActivity {
                     None
                 }
                 // seek
-                (_, key) if key== &MSG_KEY_CHAR_F => match self.player.seek(5) {
-                    Ok(_) =>{
+                (_, key) if key== &MSG_KEY_CHAR_F => if self.player.seek(5).is_ok() {
                         self.time_pos += 5;
                         self.update_progress();
                         None
-                    },
-                    Err(_) => {
+                    } else {
                         self.status = Some(Status::Stopped);
                         None
                     },
-                },
                 // seek backward
-                (_, key) if key== &MSG_KEY_CHAR_B => match self.player.seek(-5) {
-                    Ok(_) => {
+                (_, key) if key== &MSG_KEY_CHAR_B => if self.player.seek(-5).is_ok() {
                         self.time_pos -= 5;
                         None
                     }
-                    Err(_) => {
+                    else {
                         self.status = Some(Status::Stopped);
                         None
-                    }
-                },
+                    },
                 // adjust lyric delay 
                 (_, key) if key== &MSG_KEY_CHAR_CAPITAL_F => {
                    if let Some(song) = self.current_song.as_mut(){
                        if let Some(lyric) = song.parsed_lyric.as_mut() {
                            lyric.adjust_offset(self.time_pos,1000);
-                           if let Some(text) = lyric.as_lrc_text() {
-                               song.set_lyric(&text,"Adjusted");
-                           }
+                           let text = lyric.as_lrc_text();
+                           song.set_lyric(&text,"Adjusted");
                            if let Err(e) = song.save_tag() {
                                self.mount_error(e.to_string().as_ref());
                            };
@@ -151,9 +163,8 @@ impl MainActivity {
                     if let Some(song) = self.current_song.as_mut() {
                         if let Some(lyric) = song.parsed_lyric.as_mut() {
                            lyric.adjust_offset(self.time_pos,-1000);
-                           if let Some(text) = lyric.as_lrc_text() {
-                                   song.set_lyric(&text,"Adjusted");
-                           }
+                           let text = lyric.as_lrc_text();
+                           song.set_lyric(&text,"Adjusted");
                            if let Err(e) = song.save_tag() {
                                self.mount_error(e.to_string().as_ref());
                            };
@@ -245,10 +256,10 @@ impl MainActivity {
                     if let Some(Payload::One(Value::Usize(index))) = self.view.get_state(COMPONENT_TABLE_QUEUE) {
                         self.time_pos = 0;
                         if let Some(song) = self.queue_items.get(index) {
-                            if let Some(file) = &song.file {
+                            if let Some(file) = song.file() {
                                 self.player.queue_and_play(file);
                             }
-                            self.current_song = Some(song.to_owned());
+                            self.current_song = Some(song.clone());
                         }
                         self.update_photo();
                     }
@@ -410,7 +421,7 @@ impl MainActivity {
 
                 // switch lyrics
                 (_,key) if key == &MSG_KEY_CHAR_CAPITAL_T => {
-                    if let Some(mut song) = self.current_song.to_owned() {
+                    if let Some(mut song) = self.current_song.clone() {
                         if song.lyric_frames.is_empty() {
                             return None
                         }
@@ -422,12 +433,12 @@ impl MainActivity {
                             if let Ok(parsed_lyric) = Lyric::from_str(&f.text) {
                                 let tx = self.sender_message.clone();
                                 song.parsed_lyric = Some(parsed_lyric);
-                                let lang_ext = f.description.to_owned();
+                                let lang_ext = f.description.clone();
                                 self.current_song = Some(song);
                                 thread::spawn(move || {
-                                    let _ = tx.send(MessageState::Show(("Lyric switch successful".to_string(),format!("{} lyric is showing",lang_ext))));
+                                    let _drop = tx.send(MessageState::Show(("Lyric switch successful".to_string(),format!("{} lyric is showing",lang_ext))));
                                     sleep(Duration::from_secs(5));
-                                    let _ = tx.send(MessageState::Hide);
+                                    let _drop = tx.send(MessageState::Hide);
                                 });
                             }
                         }
@@ -511,9 +522,13 @@ impl MainActivity {
     pub fn update_duration(&mut self) {
         let (_new_prog, _time_pos, duration) = self.player.get_progress();
         if let Some(song) = &mut self.current_song {
-            let diff = song.duration.as_secs() as i64 - duration;
-            if diff.abs() > 1 {
-                song.update_duration();
+            let diff = song.duration().as_secs().checked_sub(duration as u64);
+            if let Some(d) = diff {
+                if d > 1 {
+                    let _drop = song.update_duration();
+                }
+            } else {
+                let _drop = song.update_duration();
             }
         }
     }
@@ -528,7 +543,7 @@ impl MainActivity {
             return;
         }
 
-        let song = match self.current_song.to_owned() {
+        let song = match self.current_song.clone() {
             Some(s) => s,
             None => return,
         };
@@ -584,6 +599,7 @@ impl MainActivity {
     }
 
     // update picture of album
+    #[allow(clippy::cast_possible_truncation, clippy::cast_possible_wrap)]
     pub fn update_photo(&mut self) {
         // if terminal is not kitty, just don't show photo
         if viuer::KittySupport::Local != viuer::get_kitty_support() {
@@ -600,32 +616,30 @@ impl MainActivity {
             Some(c) => c.clear_image(),
             None => return,
         }
-        // if no photo, just return
-        if song.picture.is_empty() {
-            return;
-        }
 
         // just show the first photo
-        if let Some(picture) = song.picture.get(0) {
+        if let Some(picture) = &song.picture {
             if let Ok(image) = image::load_from_memory(&picture.data) {
                 let (term_width, term_height) = viuer::terminal_size();
                 // Set desired image dimensions
                 let (orig_width, orig_height) = image::GenericImageView::dimensions(&image);
-                let ratio = orig_height as f64 / orig_width as f64;
+                // let ratio = f64::from(orig_height) / f64::from(orig_width);
                 let width = 20_u16;
-                let height = (width as f64 * ratio) as u16;
-                let config = viuer::Config {
-                    transparent: true,
-                    absolute_offset: true,
-                    x: term_width - width - 1,
-                    y: (term_height - height / 2 - 8) as i16 - 1,
-                    // x: term_width / 3 - width - 1,
-                    // y: (term_height - height / 2) as i16 - 2,
-                    width: Some(width as u32),
-                    height: None,
-                    ..Default::default()
-                };
-                let _ = viuer::print(&image, &config);
+                let height = (width * orig_height as u16).checked_div(orig_width as u16);
+                if let Some(height) = height {
+                    let config = viuer::Config {
+                        transparent: true,
+                        absolute_offset: true,
+                        x: term_width - width - 1,
+                        y: (term_height - height / 2 - 8) as i16 - 1,
+                        // x: term_width / 3 - width - 1,
+                        // y: (term_height - height / 2) as i16 - 2,
+                        width: Some(u32::from(width)),
+                        height: None,
+                        ..viuer::Config::default()
+                    };
+                    let _drop = viuer::print(&image, &config);
+                }
             }
         }
     }
@@ -663,7 +677,7 @@ impl MainActivity {
     pub fn update_status_line(&mut self, s: StatusLine) {
         match s {
             StatusLine::Default => {
-                let text = "Press <CTRL+H> for help.".to_string();
+                let text = format!("Press <CTRL+H> for help. Version: {}", crate::VERSION);
                 if let Some(props) = self.view.get_props(COMPONENT_LABEL_HELP) {
                     let props = LabelPropsBuilder::from(props)
                         .with_text(text)
@@ -753,4 +767,13 @@ impl MainActivity {
             }
         }
     }
+
+    // update queue items when loading
+    pub fn update_queue_items(&mut self) {
+        if let Ok(queue_items) = self.receiver_queueitems.try_recv() {
+            self.queue_items = queue_items;
+            self.sync_queue();
+            self.redraw = true;
+        }
+    }
 }
