@@ -28,11 +28,15 @@ use super::{
     COMPONENT_TE_RADIO_TAG, COMPONENT_TE_SCROLLTABLE_OPTIONS, COMPONENT_TE_SELECT_LYRIC,
     COMPONENT_TE_TEXTAREA_LYRIC, COMPONENT_TE_TEXT_ERROR, COMPONENT_TE_TEXT_HELP,
 };
+use crate::ui::keymap::{
+    MSG_KEY_CHAR_CAPITAL_G, MSG_KEY_CHAR_CAPITAL_Q, MSG_KEY_CHAR_G, MSG_KEY_CHAR_H, MSG_KEY_CHAR_J,
+    MSG_KEY_CHAR_K, MSG_KEY_CHAR_L, MSG_KEY_CHAR_S, MSG_KEY_CTRL_H, MSG_KEY_ENTER, MSG_KEY_ESC,
+    MSG_KEY_TAB,
+};
 use crate::{
     song::Song,
-    songtag::songtag_search,
+    songtag::search,
     ui::activity::main::{StatusLine, TransferState},
-    ui::keymap::*,
 };
 use std::path::Path;
 use std::str::FromStr;
@@ -48,6 +52,11 @@ impl TagEditorActivity {
     ///
     /// Update auth activity model based on msg
     /// The function exits when returns None
+    #[allow(
+        clippy::too_many_lines,
+        clippy::needless_pass_by_value,
+        clippy::cognitive_complexity
+    )]
     pub fn update(&mut self, msg: Option<(String, Msg)>) -> Option<(String, Msg)> {
         let ref_msg: Option<(&str, &Msg)> = msg.as_ref().map(|(s, msg)| (s.as_str(), msg));
         match ref_msg {
@@ -93,12 +102,12 @@ impl TagEditorActivity {
                             if let Some(Payload::One(Value::Str(artist))) =
                                 self.view.get_state(COMPONENT_TE_INPUT_ARTIST)
                             {
-                                song.artist = Some(artist);
+                                song.set_artist(&artist);
                             }
                             if let Some(Payload::One(Value::Str(title))) =
                                 self.view.get_state(COMPONENT_TE_INPUT_SONGNAME)
                             {
-                                song.title = Some(title);
+                                song.set_title(&title);
                             }
                             match song.save_tag() {
                                 Ok(()) => {
@@ -106,7 +115,7 @@ impl TagEditorActivity {
                                         self.exit_reason =
                                             Some(ExitReason::NeedRefreshPlaylist(file.to_string()));
                                     }
-                                    self.init_by_song(&song)
+                                    self.init_by_song(&song);
                                 }
                                 Err(e) => self.mount_error(&e.to_string()),
                             };
@@ -124,22 +133,19 @@ impl TagEditorActivity {
                             }
                             if let Some(mut song) = self.song.clone() {
                                 let song_tag = self.songtag_options.get(index)?;
-                                let lang_ext = song_tag
-                                    .lang_ext
-                                    .to_owned()
-                                    .unwrap_or_else(|| String::from("eng"));
-                                if let Some(artist) = &song_tag.artist {
-                                    song.artist = Some(artist.to_owned());
+                                let lang_ext = song_tag.lang_ext().unwrap_or("eng");
+                                if let Some(artist) = song_tag.artist() {
+                                    song.set_artist(artist);
                                 }
-                                if let Some(title) = &song_tag.title {
-                                    song.title = Some(title.to_owned());
+                                if let Some(title) = song_tag.title() {
+                                    song.set_title(title);
                                 }
-                                if let Some(album) = &song_tag.album {
-                                    song.album = Some(album.to_owned());
+                                if let Some(album) = song_tag.album() {
+                                    song.set_album(album);
                                 }
 
                                 if let Ok(lyric_string) = song_tag.fetch_lyric() {
-                                    song.set_lyric(&lyric_string, &lang_ext);
+                                    song.set_lyric(&lyric_string, lang_ext);
                                 }
                                 if let Ok(artwork) = song_tag.fetch_photo() {
                                     song.set_photo(artwork);
@@ -152,7 +158,7 @@ impl TagEditorActivity {
                                                 ExitReason::NeedRefreshPlaylist(file.to_string()),
                                             );
                                         }
-                                        self.init_by_song(&song)
+                                        self.init_by_song(&song);
                                     }
                                     Err(e) => self.mount_error(&e.to_string()),
                                 }
@@ -171,7 +177,7 @@ impl TagEditorActivity {
                     {
                         if let Some(song_tag) = self.songtag_options.get(index) {
                             if let Some(song) = &self.song {
-                                if let Some(file) = &song.file {
+                                if let Some(file) = song.file() {
                                     if let Err(e) = song_tag.download(file, self.sender.clone()) {
                                         self.mount_error(&e.to_string());
                                     }
@@ -212,8 +218,10 @@ impl TagEditorActivity {
                     None
                 }
 
-                (COMPONENT_TE_INPUT_ARTIST, Msg::OnSubmit(Payload::One(Value::Str(_))))
-                | (COMPONENT_TE_INPUT_SONGNAME, Msg::OnSubmit(Payload::One(Value::Str(_)))) => {
+                (
+                    COMPONENT_TE_INPUT_ARTIST | COMPONENT_TE_INPUT_SONGNAME,
+                    Msg::OnSubmit(Payload::One(Value::Str(_))),
+                ) => {
                     // Get Tag
                     let mut search_str = String::new();
                     if let Some(Payload::One(Value::Str(artist))) =
@@ -231,8 +239,8 @@ impl TagEditorActivity {
 
                     if search_str.len() < 4 {
                         if let Some(song) = &self.song {
-                            if let Some(file) = &song.file {
-                                let p: &Path = Path::new(file.as_str());
+                            if let Some(file) = song.file() {
+                                let p: &Path = Path::new(file);
                                 if let Some(stem) = p.file_stem() {
                                     search_str = stem.to_string_lossy().to_string();
                                 }
@@ -240,7 +248,7 @@ impl TagEditorActivity {
                         }
                     }
 
-                    songtag_search(&search_str, self.sender_songtag.clone());
+                    search(&search_str, self.sender_songtag.clone());
                     None
                 }
 
