@@ -34,19 +34,20 @@ use tuirealm::{
 
 // -- states
 
+#[derive(Default)]
 struct OwnStates {
     counter: usize,
     focus: bool,
 }
 
-impl Default for OwnStates {
-    fn default() -> Self {
-        OwnStates {
-            counter: 0,
-            focus: false,
-        }
-    }
-}
+// impl Default for OwnStates {
+//     fn default() -> Self {
+//         Self {
+//             counter: 0,
+//             focus: false,
+//         }
+//     }
+// }
 
 // impl OwnStates {
 //     pub fn incr(&mut self) {
@@ -59,13 +60,14 @@ impl Default for OwnStates {
 const PROP_VALUE: &str = "value";
 const PROP_LABEL: &str = "title";
 
+#[allow(clippy::module_name_repetitions)]
 pub struct CounterPropsBuilder {
     props: Option<Props>,
 }
 
 impl Default for CounterPropsBuilder {
     fn default() -> Self {
-        CounterPropsBuilder {
+        Self {
             props: Some(Props::default()),
         }
     }
@@ -97,7 +99,7 @@ impl PropsBuilder for CounterPropsBuilder {
 
 impl From<Props> for CounterPropsBuilder {
     fn from(props: Props) -> Self {
-        CounterPropsBuilder { props: Some(props) }
+        Self { props: Some(props) }
     }
 }
 
@@ -167,7 +169,7 @@ impl Counter {
         if let Some(PropPayload::One(PropValue::Usize(val))) = props.own.get(PROP_VALUE) {
             states.counter = *val;
         }
-        Counter { props, states }
+        Self { props, states }
     }
 }
 
@@ -183,9 +185,10 @@ impl Component for Counter {
             let text: String = format!("{} ({})", prefix, self.states.counter);
             let block: Block =
                 tui_realm_stdlib::utils::get_block(&self.props.borders, None, self.states.focus);
-            let (fg, bg) = match self.states.focus {
-                true => (self.props.foreground, self.props.background),
-                false => (Color::Reset, Color::Reset),
+            let (fg, bg) = if self.states.focus {
+                (self.props.foreground, self.props.background)
+            } else {
+                (Color::Reset, Color::Reset)
             };
             render.render_widget(
                 Paragraph::new(text).block(block).style(
@@ -207,10 +210,10 @@ impl Component for Counter {
         }
         self.props = props;
         // Msg none
-        if prev_value != self.states.counter {
-            Msg::OnChange(self.get_state())
-        } else {
+        if prev_value == self.states.counter {
             Msg::None
+        } else {
+            Msg::OnChange(self.get_state())
         }
     }
 
